---
title: <span class="badge object-type-scalar"></span> MilligramsPerDecilitre
---
# <span class="badge object-type-scalar"></span> MilligramsPerDecilitre

Concentration: milligrams per decilitre (mg/dL)

## Definition

```python
# Concentration: milligrams per decilitre (mg/dL)
MilligramsPerDecilitre: typing.Literal["conmgdL"] = "conmgdL"
```
